@@ -28,7 +28,6 @@ class Hero(Base):
 	image = Column(String)
 	icon = Column(String)
 	portrait = Column(String)
-	talents = Column(String)
 	color = Column(String)
 	legs = Column(Integer)
 
@@ -58,8 +57,9 @@ class Hero(Base):
 	is_melee = Column(Boolean)
 	material = Column(String)
 
+	abilities = relationship("Ability", order_by="Ability.slot", back_populates="hero")
+	talents = relationship("Talent", order_by="Talent.slot")
 	responses = relationship("Response", back_populates="hero")
-	abilities = relationship("Ability", back_populates="hero")
 	voice = relationship("Voice", uselist=False, back_populates="hero")
 
 	json_data = Column(String)
@@ -72,7 +72,7 @@ class Ability(Base):
 
 	id = Column(Integer, primary_key=True)
 	name = Column(String)
-	hero_id = Column(Integer, ForeignKey("heroes.id"))
+	hero_id = Column(Integer, ForeignKey("heroes.id"), nullable=True)
 
 	behavior = Column(String)
 	damage_type = Column(String)
@@ -87,24 +87,67 @@ class Ability(Base):
 	duration = Column(String)
 	damage = Column(String)
 	mana_cost = Column(String)
+	charges = Column(String)
 	ability_special = Column(String)
 
-	ability_slot = Column(Integer)
+	slot = Column(Integer)
 	icon = Column(String)
 
 	localized_name = Column(String)
 	description = Column(String)
 	lore = Column(String)
 	note = Column(String)
-	aghanim = Column(String)
+	scepter_description = Column(String)
+	scepter_grants = Column(Boolean)
+	shard_description = Column(String)
+	shard_grants = Column(Boolean)
 
 	json_data = Column(String)
 
 	hero = relationship("Hero", back_populates="abilities")
+	talent_links = relationship("Talent", back_populates="ability")
+
+	@property
+	def aghanim(self):
+		return self.scepter_description
+
+	@property
+	def aghanim_grants(self):
+		return self.scepter_grants
+
+	@property
+	def is_talent(self):
+		return len(self.talent_links) > 0
 
 	def __repr__(self):
 		return "Ability: %s" % (self.localized_name)
 
+class Talent(Base):
+	__tablename__ = 'talents'
+
+	hero_id = Column(Integer, ForeignKey("heroes.id"), primary_key=True, nullable=True)
+	ability_id = Column(Integer, ForeignKey("abilities.id"), primary_key=True)
+	slot = Column(Integer)
+	linked_abilities = Column(String)
+
+	ability = relationship("Ability", back_populates="talent_links")
+
+	@property
+	def localized_name(self):
+		return self.ability.localized_name
+
+	@property
+	def level(self):
+		return ((self.slot // 2) * 5) + 10
+
+	@property
+	def is_right_side(self):
+		return (self.slot % 2) == 0
+
+	def __repr__(self):
+		return "Talent: %s" % (self.localized_name)
+
+
 class Item(Base):
 	__tablename__ = 'items'
 
@@ -124,6 +167,7 @@ class Item(Base):
 	secret_shop = Column(Boolean)
 	neutral_tier = Column(String)
 	ability_special = Column(String)
+	recipe = Column(String)
 
 	json_data = Column(String)
 
